@@ -1,5 +1,6 @@
 est.arma.wge=function (x, p = 0, q = 0,factor=TRUE) 
 {
+    xbar=mean(x)
     x = x - mean(x)
     w = getOption("warn")
     options(warn = -1)
@@ -24,7 +25,7 @@ est.arma.wge=function (x, p = 0, q = 0,factor=TRUE)
         se.theta = v[(p + 1):(p + q)]
     }
 
-if (factor==TRUE & p>0) {factor.wge(phi=phi)}
+if (factor==TRUE & p>0) {factor.wge(phi=phi,theta=theta)}
 res=backcast.wge(x,phi=phi,theta=theta,n.back=50)
 avar=0
 n=length(x)
@@ -33,7 +34,7 @@ avar=avar/n
 aic=log(avar)+2*(p+q+1)/n
 bic=log(avar)+(p+q+1)*log(n)/n
 aicc=log(avar)+(n+p+q+1)/(n-p-q-3)
-out1 = list(phi = phi, theta = theta, res=res,avar=avar, aic=aic,aicc=aicc,bic=bic, 
+out1 = list(phi = phi, theta = theta, res=res,avar=avar, xbar=xbar,aic=aic,aicc=aicc,bic=bic, 
         se.phi = se.phi, se.theta = se.theta)
 #    a = .innovation.update(x, a)
     return(out1)
